@@ -1,3 +1,4 @@
+from datetime import datetime, timezone
 from typing import List, Optional
 
 from fastapi import Cookie, Depends, Form, Query, Response
@@ -50,6 +51,7 @@ async def get_authorize_client(
 
 async def get_authorize_redirect_uri(
     redirect_uri: Optional[str] = Query(None),
+    client: Client = Depends(get_authorize_client),
     _=Depends(get_gettext),
 ) -> str:
     if redirect_uri is None:
@@ -57,6 +59,13 @@ async def get_authorize_redirect_uri(
             AuthorizeError.get_invalid_redirect_uri(_("redirect_uri is missing"))
         )
 
+    if redirect_uri not in client.redirect_uris:
+        raise AuthorizeException(
+            AuthorizeError.get_invalid_redirect_uri(
+                _("redirect_uri is not authorized for this client")
+            )
+        )
+
     return redirect_uri
 
 
@@ -160,6 +169,22 @@ async def get_authorize_screen(
     return screen
 
 
+async def has_valid_session_token(
+    max_age: Optional[int] = Query(None),
+    session_token: Optional[SessionToken] = Depends(get_session_token),
+) -> bool:
+    if session_token is None:
+        return False
+
+    if max_age is not None:
+        session_age = (
+            datetime.now(timezone.utc) - session_token.created_at
+        ).total_seconds()
+        return session_age < max_age
+
+    return True
+
+
 async def get_optional_login_session(
     token: Optional[str] = Cookie(None, alias=settings.login_session_cookie_name),
     login_session_manager: LoginSessionManager = Depends(get_login_session_manager),
