@@ -1,5 +1,3 @@
-from fief.managers.account import AccountManager
-from fief.managers.account_user import AccountUserManager
 from fief.managers.admin_api_key import AdminAPIKeyManager
 from fief.managers.admin_session_token import AdminSessionTokenManager
 from fief.managers.authorization_code import AuthorizationCodeManager
@@ -11,10 +9,12 @@ from fief.managers.refresh_token import RefreshTokenManager
 from fief.managers.session_token import SessionTokenManager
 from fief.managers.tenant import TenantManager
 from fief.managers.user import UserManager
+from fief.managers.workspace import WorkspaceManager
+from fief.managers.workspace_user import WorkspaceUserManager
 
 __all__ = [
-    "AccountManager",
-    "AccountUserManager",
+    "WorkspaceManager",
+    "WorkspaceUserManager",
     "AdminAPIKeyManager",
     "AdminSessionTokenManager",
     "AuthorizationCodeManager",
