@@ -3,13 +3,13 @@ from datetime import datetime
 from typing import List, Optional
 
 from pydantic import UUID4
-from sqlalchemy import TIMESTAMP, Column, ForeignKey
+from sqlalchemy import Column, ForeignKey
 from sqlalchemy.orm import relationship
 from sqlalchemy.sql.sqltypes import JSON, String
 
 from fief.models.base import WorkspaceBase
 from fief.models.client import Client
-from fief.models.generics import GUID, CreatedUpdatedAt, UUIDModel
+from fief.models.generics import GUID, CreatedUpdatedAt, TIMESTAMPAware, UUIDModel
 from fief.models.user import User
 
 
@@ -25,7 +25,7 @@ class AuthorizationCode(UUIDModel, CreatedUpdatedAt, WorkspaceBase):
     )
     redirect_uri: str = Column(String(length=2048), nullable=False)
     scope: List[str] = Column(JSON, nullable=False, default=list)
-    authenticated_at: datetime = Column(TIMESTAMP(timezone=True), nullable=False)
+    authenticated_at: datetime = Column(TIMESTAMPAware(timezone=True), nullable=False)
     nonce: Optional[str] = Column(String(length=255), nullable=True)
 
     user_id: UUID4 = Column(GUID, ForeignKey(User.id, ondelete="CASCADE"), nullable=False)  # type: ignore
